@@ -1,15 +1,20 @@
-package Dist::Zilla::Plugin::PodWeaver;
+package Dist::Zilla::Plugin::PodWeaver 4.009;
 # ABSTRACT: weave your Pod together from configuration and Dist::Zilla
-$Dist::Zilla::Plugin::PodWeaver::VERSION = '4.007';
+
 use Moose;
-use List::MoreUtils qw(any);
 use Pod::Weaver 3.100710; # logging with proxies
-with(
-  'Dist::Zilla::Role::FileMunger',
-  'Dist::Zilla::Role::FileFinderUser' => {
-    default_finders => [ ':InstallModules', ':ExecFiles' ],
-  },
-);
+with 'Dist::Zilla::Role::FileMunger',
+     'Dist::Zilla::Role::FileFinderUser' => {
+       default_finders => [ ':InstallModules', ':ExecFiles' ],
+     };
+
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
 
 use namespace::autoclean;
 
@@ -111,8 +116,8 @@ around dump_config => sub
   };
 
   $our->{plugins} = [];
-  for my $plugin (@{ $self->weaver->plugins }) {
-    push @{ $our->{plugins} }, {
+  for my $plugin ($self->weaver->plugins->@*) {
+    push $our->{plugins}->@*, {
       class   => $plugin->meta->name,
       name    => $plugin->plugin_name,
       version => $plugin->VERSION,
@@ -131,7 +136,7 @@ sub munge_files {
   require Pod::Weaver;
   require Pod::Weaver::Config::Assembler;
 
-  $self->munge_file($_) for @{ $self->found_files };
+  $self->munge_file($_) for $self->found_files->@*;
 }
 
 sub munge_file {
@@ -162,15 +167,18 @@ sub munge_perl_string {
 sub munge_pod {
   my ($self, $file) = @_;
 
+  my @authors = $self->zilla->authors;
+  @authors = $authors[0]->@* if @authors == 1 && ref $authors[0];
+
   my $new_content = $self->munge_perl_string(
     $file->content,
     {
-      zilla    => $self->zilla,
-      filename => $file->name,
-      version  => $self->zilla->version,
-      license  => $self->zilla->license,
-      authors  => $self->zilla->authors,
-      distmeta => $self->zilla->distmeta,
+      zilla    => scalar $self->zilla,
+      filename => scalar $file->name,
+      version  => scalar $self->zilla->version,
+      license  => scalar $self->zilla->license,
+      authors  => \@authors,
+      distmeta => scalar $self->zilla->distmeta,
     },
   );
 
@@ -197,13 +205,24 @@ Dist::Zilla::Plugin::PodWeaver - weave your Pod together from configuration and
 
 =head1 VERSION
 
-version 4.007
+version 4.009
 
 =head1 DESCRIPTION
 
 [PodWeaver] is the bridge between L<Dist::Zilla> and L<Pod::Weaver>.  It rips
 apart your kinda-Pod and reconstructs it as boring old real Pod.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 finder
@@ -248,7 +267,7 @@ Otherwise, it will use the default configuration.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 CONTRIBUTORS
 
@@ -280,7 +299,7 @@ Yasutaka ATARASHI <yakex@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
